==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/ru.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Информация о ЦП недоступна",
    "Load average" : "Средняя нагрузка",
    "Last minute" : "За последнюю минуту",
    "Memory info not available" : "Информация о памяти недоступна",
    "Total" : "Всего",
    "Current usage" : "Текущая нагрузка",
    "Users" : "Пользователи",
    "Groups" : "Группы",
    "Links" : "Ссылки",
    "Federated sent" : "Федеративно отправлено",
    "Federated received" : "Федеративно получено",
    "Last 24 hours" : "За 24 часа",
    "Last 1 hour" : "За 1 час",
    "Last 5 mins" : "За 5 минут",
    "Copy" : "Копировать",
    "Copied!" : "Скопировано!",
    "Not supported!" : "Не поддерживается!",
    "Press ⌘-C to copy." : "Нажмите ⌘-C для копирования. ",
    "Press Ctrl-C to copy." : "Нажмите Ctrl-C для копирования.",
    "Monitoring" : "Мониторинг",
    "Monitoring app with useful server information" : "Приложение мониторинга с полезной информацией о сервере",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Предоставляет полезную информацию о сервере, такую как загрузка процессора, использование ОЗУ, диска, количество пользователей и т.д.",
    "CPU load" : "Загрузка процессора",
    "Memory usage" : "Использование памяти",
    "Active users" : "Активные пользователи",
    "Shares" : "Общие ресурсы",
    "Storage" : "Хранилище",
    "Users:" : "Пользователей:",
    "Files:" : "Файлы:",
    "Storages:" : "Хранилища:",
    "Free Space:" : "Свободно:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Версия:",
    "Apps installed:" : "Установленные приложения:",
    "Apps updates available:" : "Доступные обновления:",
    "PHP" : "PHP",
    "Memory Limit:" : "Ограничение памяти:",
    "Max Execution Time:" : "Максимальное время выполнения:",
    "Upload max size:" : "Максимальный размер для загрузки:",
    "Database" : "База данных",
    "Type:" : "Тип:",
    "Size:" : "Размер:",
    "External monitoring tool" : "Внешний мониторинг",
    "You can connect an external monitoring tool by using this end point:" : "Вы можете подключить внешний мониторинг используя этот адрес:",
    "Did you know?" : "Совет:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Если к строке URL добавить «?format=json», то ответ сервера будет в формате JSON."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/ru.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Информация о ЦП недоступна",
    "Load average" : "Средняя нагрузка",
    "Last minute" : "За последнюю минуту",
    "Memory info not available" : "Информация о памяти недоступна",
    "Total" : "Всего",
    "Current usage" : "Текущая нагрузка",
    "Users" : "Пользователи",
    "Groups" : "Группы",
    "Links" : "Ссылки",
    "Mails" : "Почты",
    "Federated sent" : "Федеративно отправлено",
    "Federated received" : "Федеративно получено",
    "Talk conversations" : "Обсуждения",
    "24 hours" : "24 часа",
    "1 hour" : "1 час",
    "5 mins" : "5 минут",
    "Copy" : "Копировать",
    "Copied!" : "Скопировано!",
    "Not supported!" : "Не поддерживается!",
    "Press ⌘-C to copy." : "Нажмите ⌘-C для копирования. ",
    "Press Ctrl-C to copy." : "Нажмите Ctrl-C для копирования.",
    "System" : "Система",
    "Monitoring" : "Мониторинг",
    "Monitoring app with useful server information" : "Приложение мониторинга с полезной информацией о сервере",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Предоставляет полезную информацию о сервере, такую как загрузка процессора, использование ОЗУ, диска, количество пользователей и т.д.",
    "Operating System" : "Операционная система",
    "CPU" : "Процессор",
    "Memory" : "Память",
    "Server time" : "Серверное время",
    "Uptime" : "Время работы",
    "Time Servers" : "Серверы времени",
    "Load" : "Нагрузка",
    "Disk" : "Диск",
    "Mount" : "Монтирование",
    "Filesystem" : "Файловая система",
    "Size" : "Размер",
    "Available" : "Доступно",
    "Used" : "Использовано",
    "You will get a notification once one of your disks is nearly full." : "Когда один из ваших дисков будет практически полностью заполнен, вы получите уведомление.",
    "Files:" : "Файлы:",
    "Storages:" : "Хранилища:",
    "Free Space:" : "Свободно:",
    "Network" : "Сеть",
    "Hostname" : "Имя хоста",
    "DNS" : "DNS",
    "Gateway" : "Шлюз",
    "Status" : "Статус",
    "Speed" : "Скорость",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Активные пользователи",
    "Total users:" : "Всего пользователей:",
    "Shares" : "Общие ресурсы",
    "PHP" : "PHP",
    "Version:" : "Версия:",
    "Memory Limit:" : "Ограничение памяти:",
    "Max Execution Time:" : "Максимальное время выполнения:",
    "Upload max size:" : "Максимальный размер для отправки:",
    "Database" : "База данных",
    "Type:" : "Тип:",
    "Size:" : "Размер:",
    "External monitoring tool" : "Внешний мониторинг",
    "You can connect an external monitoring tool by using this end point:" : "Вы можете подключить внешний мониторинг используя этот адрес:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Если к строке URL добавить «?format=json», то ответ сервера будет в формате JSON.",
    "Last 24 hours" : "За 24 часа",
    "Last 1 hour" : "За 1 час",
    "Last 5 mins" : "За 5 минут",
    "CPU load" : "Загрузка процессора",
    "Memory usage" : "Использование памяти",
    "Storage" : "Хранилище",
    "Users:" : "Пользователей:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Установленные приложения:",
    "Apps updates available:" : "Доступные обновления:",
    "Did you know?" : "Совет:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Если к строке URL добавить «?format=json», то ответ сервера будет в формате JSON."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
